"""Allow command line user promotion."""
from django.contrib.auth.models import User
from django.core.management.base import BaseCommand, CommandError


class Command(BaseCommand):
    """Promote a user to staff, admin, or superuser."""

    help = 'Promote a user to superuser'

    def add_arguments(self, parser):
        """Get the target's username."""

        parser.add_argument('username', type=str)

    def handle(self, *args, **options):
        """Try to promote user, or fail."""

        username = options.get('username')
        try:
            user = User.objects.get(username=username)
        except User.DoesNotExist:
            raise CommandError('User {} does not exist'.format(username))
        user.is_superuser = True
        user.is_staff = True
        user.is_admin = True
        user.save()

        self.stdout.write(self.style.SUCCESS(
            'Successfully promoted user {}'.format(username)
        ))


__all__ = ('Command',)



from os import path
from codecs import open

from setuptools import setup, find_packages

HERE = path.abspath(path.dirname(__file__))
PROMOTER_VER = '1.0.1'

setup(
    name='django-promoter',

    version=PROMOTER_VER,

    description='Django commands used to promote or demote users',
    long_description=open('README.rst').read(),

    url='https://github.com/numberly/django-promoter',

    author='Theo Massard',
    author_email='theo.massard@1000mercis.com',

    license='MIT',

    classifiers=[
        'Development Status :: 5 - Production/Stable',

        'Environment :: Console',

        'Framework :: Django',

        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',

        'License :: OSI Approved :: MIT License',

        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
    ],

    keywords='django auth admin cli python3.5',

    packages=find_packages(),
)
